#RequireAdmin
#NoTrayIcon
#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_icon=Icons\miguiresource_600.ico
#AutoIt3Wrapper_outfile=AdminTrayTaskImport.exe
#AutoIt3Wrapper_Compression=4
#AutoIt3Wrapper_Res_Comment=Admin Tray Task Importer
#AutoIt3Wrapper_Res_Description=Imports Admin Tray to run at user logon with administrative permissions.
#AutoIt3Wrapper_Res_Fileversion=0.1.0.0
#AutoIt3Wrapper_Res_LegalCopyright=JSComputerTech
#AutoIt3Wrapper_Res_SaveSource=y
#AutoIt3Wrapper_Res_Language=1033
#AutoIt3Wrapper_Run_Tidy=y
#Tidy_Parameters=/sf
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****

#cs ----------------------------------------------------------------------------
	
	AutoIt Version: 			3.2.10.0
	
	Script Name:				AdminTrayTaskImport.au3
	http://www.autoitscript.com/forum/index.php?showtopic=58997
	
	Author:						James R Feig III
	AutoITScript.com Forum id:	toyotabedzrock
	
	Script Function:
	Schedules Admin Tray to run at logon, with administrator privileges, for the current user.
	
#ce ----------------------------------------------------------------------------

#Include <Date.au3>
#include <File.au3>

Opt("OnExitFunc", "OnAutoItExit")
Opt("RunErrorsFatal", 0)

Const $taskFile = "task.xml"
Const $taskName = '"Admin Tray AutoRun"'
Const $OsCheck = "WIN_VISTA"

Const $XmlAuthorLine = "<Author>XmlAuthorLine</Author>"
Const $XmlUserIDLine = "<UserId>XmlUserIDLine</UserId>"
Const $RunTaskAs = @LogonDomain & "\" & @UserName
Const $XmlAuthorLineReplace = "<Author>" & $RunTaskAs & "</Author>"
Const $XmlUserIDLineReplace = "<UserId>" & $RunTaskAs & "</UserId>"

Const $AdminAppExe = "\Admin Tray.exe"
Const $XmlCommandLine = "<Command>XmlCommandLine</Command>"
Const $XmlCommandLineReplace = '<Command>"' & @ScriptDir & $AdminAppExe & '"</Command>'

$LocalTime = _Date_Time_GetLocalTime()
$LocalTimeArray = _Date_Time_SystemTimeToArray($LocalTime)
$FormatedTaskTime = $LocalTimeArray[2] & "-" & $LocalTimeArray[0] & "-" & $LocalTimeArray[1] & "T" & $LocalTimeArray[3] & ":" & $LocalTimeArray[4] & ":" & $LocalTimeArray[5] & "." & $LocalTimeArray[6]

Const $XmlDateLine = "<Date>XmlDateLine</Date>"
Const $XmlDateLineReplace = "<Date>" & $FormatedTaskTime & "</Date>"

$IsTaskScheduled = RunWait("schtasks /Query /TN " & $taskName, "", @SW_HIDE)



If @OSVersion <> $OsCheck Then
	
	MsgBox(16, "Wrong OS", "This program is only compatible with Windows Vista")
	Exit
	
EndIf

$CurrentState = _CheckParameters()

If $CurrentState = 0 Then
	
	_RemoveTask()
	Exit

EndIf

FileInstall("Template\task.xml", "", 1)

If $CurrentState = 1 Then
	
	_ImportTask()
	
EndIf

Exit



Func _CheckCommandLineInput()
	
	
	If $CmdLine[0] > 1 Then
		
		MsgBox(16, "Error Scheduling task", "The Scheduler recieved to many commandline paramaters")
		Exit
		
	EndIf
	
	
	If $CmdLine[1] <> 1 And $CmdLine[1] <> 0 Then
		
		MsgBox(16, "Invalid Parameter", "Invalid Parameter, use 0 to delete the task or 1 to install, if you do not add a parameter it will check to see if it is installed and uninstall or install itself.")
		Exit
		
	EndIf
	
	
	If $CmdLine[1] = 1 And $IsTaskScheduled = 1 Then
		
		Return 1
		
	ElseIf $CmdLine[1] = 1 And $IsTaskScheduled = 0 Then
		
		If MsgBox(35, "Task Already Scheduled", "This task is already scheduled. Would you like to REMOVE the task?") = 6 Then
			
			Return 0
			
		Else
			
			Exit
			
		EndIf
		
	ElseIf $CmdLine[1] = 0 And $IsTaskScheduled = 0 Then
		
		Return 0
		
	ElseIf $CmdLine[1] = 0 And $IsTaskScheduled = 1 Then
		
		If MsgBox(35, "Task Not Found", "This task is NOT scheduled. Would you like to IMPORT the task now?") = 6 Then
			
			Return 1
			
		Else
			
			Exit
			
		EndIf
		
		
	EndIf
	
EndFunc   ;==>_CheckCommandLineInput



;Functions
Func _CheckParameters()
	
	If $CmdLine[0] >= 1 Then
		
		$ValidatedCmd = _CheckCommandLineInput()
		Return $ValidatedCmd
		
	EndIf
	
	
	If $IsTaskScheduled = 0 Then
		
		Return 0
		
	ElseIf $IsTaskScheduled = 1 Then
		
		Return 1
		
	EndIf
	
EndFunc   ;==>_CheckParameters



Func _ImportTask()
	
	_UpdateFileParameters()
	
	$cmdID = RunWait('schtasks /Create /XML "' & $taskFile & '" /TN ' & $taskName, @ScriptDir, @SW_HIDE)
	
	If @error = 1 OR $cmdID = 1 Then
		
		MsgBox(16, "Error", "Error running schtasks.exe to import task.")
		Exit
		
	EndIf
	
	Exit

EndFunc   ;==>_ImportTask

Func _RemoveTask()
	
	RunWait('schtasks /Delete /TN ' & $taskName & ' /F', "", @SW_HIDE)
	
	If @error = 1 Then
		
		MsgBox(16, "Error", "The task was unable to be removed.")
		Exit
		
	EndIf
	
	Exit
	
EndFunc   ;==>_RemoveTask

Func _UpdateFileParameters()
	
	If FileExists($taskFile) Then
		
		_ReplaceStringInFile($taskFile, $XmlAuthorLine, $XmlAuthorLineReplace, 1, 0)
		_ReplaceStringInFile($taskFile, $XmlUserIDLine, $XmlUserIDLineReplace, 1, 1)
		_ReplaceStringInFile($taskFile, $XmlDateLine, $XmlDateLineReplace, 1, 0)
		_ReplaceStringInFile($taskFile, $XmlCommandLine, $XmlCommandLineReplace, 1, 0)
		
	Else
		
		MsgBox(16, "File Error", $taskFile & " Does NOT exist.")
		Exit
		
	EndIf
	
EndFunc   ;==>_UpdateFileParameters


Func OnAutoItExit()

	FileDelete($taskFile)
	
EndFunc   ;==>OnAutoItExit